summaryrefslogtreecommitdiffstats
path: root/kded
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 01:04:16 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 01:04:16 -0600
commit5159cd2beb2e87806a5b54e9991b7895285c9d3e (patch)
tree9b70e8be47a390f8f4d56ead812ab0c9dad88709 /kded
parentc17cb900dcf52b8bd6dc300d4f103392900ec2b4 (diff)
downloadtdelibs-5159cd2beb2e87806a5b54e9991b7895285c9d3e.tar.gz
tdelibs-5159cd2beb2e87806a5b54e9991b7895285c9d3e.zip
Rename a number of libraries and executables to avoid conflicts with KDE4
Diffstat (limited to 'kded')
-rw-r--r--kded/CMakeLists.txt30
-rw-r--r--kded/DESIGN4
-rw-r--r--kded/Makefile.am22
-rw-r--r--kded/README.kded16
-rw-r--r--kded/kded.cpp16
-rw-r--r--kded/kded.h2
-rw-r--r--kded/kdedmodule.cpp2
-rw-r--r--kded/tde-menu.cpp (renamed from kded/kde-menu.cpp)10
-rw-r--r--kded/tdebuildsycoca.cpp (renamed from kded/kbuildsycoca.cpp)44
-rw-r--r--kded/tdebuildsycoca.h (renamed from kded/kbuildsycoca.h)6
-rw-r--r--kded/tdemimelist.cpp (renamed from kded/kmimelist.cpp)0
11 files changed, 76 insertions, 76 deletions
diff --git a/kded/CMakeLists.txt b/kded/CMakeLists.txt
index 903126ca8..ee693fb4a 100644
--- a/kded/CMakeLists.txt
+++ b/kded/CMakeLists.txt
@@ -18,8 +18,8 @@ include_directories(
${CMAKE_SOURCE_DIR}/dcop
${CMAKE_SOURCE_DIR}/tdecore
${CMAKE_SOURCE_DIR}/tdeui
- ${CMAKE_SOURCE_DIR}/kio
- ${CMAKE_SOURCE_DIR}/kio/kio
+ ${CMAKE_SOURCE_DIR}/tdeio
+ ${CMAKE_SOURCE_DIR}/tdeio/tdeio
)
link_directories(
@@ -51,16 +51,16 @@ set( ${target}_SRCS
# modules need this library
tde_add_tdeinit_executable( ${target} AUTOMOC EXPORT
SOURCES ${${target}_SRCS}
- LINK kio-shared
+ LINK tdeio-shared
)
-#### kbuildsycoca ###############################
+#### tdebuildsycoca ###############################
-set( target kbuildsycoca )
+set( target tdebuildsycoca )
set( ${target}_SRCS
- kbuildsycoca.cpp kbuildservicetypefactory.cpp
+ tdebuildsycoca.cpp kbuildservicetypefactory.cpp
kbuildservicefactory.cpp kbuildservicegroupfactory.cpp
kbuildimageiofactory.cpp kbuildprotocolinfofactory.cpp
kctimefactory.cpp vfolder_menu.cpp
@@ -68,7 +68,7 @@ set( ${target}_SRCS
tde_add_tdeinit_executable( ${target} AUTOMOC
SOURCES ${${target}_SRCS}
- LINK kio-shared
+ LINK tdeio-shared
)
@@ -87,31 +87,31 @@ tde_add_executable( ${target}
)
-#### kde-menu ###################################
+#### tde-menu ###################################
-set( target kde-menu )
+set( target tde-menu )
set( ${target}_SRCS
- kde-menu.cpp
+ tde-menu.cpp
)
tde_add_executable( ${target}
SOURCES ${${target}_SRCS}
- LINK kio-shared
+ LINK tdeio-shared
DESTINATION ${BIN_INSTALL_DIR}
)
-#### kmimelist ##################################
+#### tdemimelist ##################################
-set( target kmimelist )
+set( target tdemimelist )
set( ${target}_SRCS
- kmimelist.cpp
+ tdemimelist.cpp
)
tde_add_executable( ${target}
SOURCES ${${target}_SRCS}
- LINK kio-shared
+ LINK tdeio-shared
DESTINATION ${BIN_INSTALL_DIR}
)
diff --git a/kded/DESIGN b/kded/DESIGN
index e6653807b..0fffb0456 100644
--- a/kded/DESIGN
+++ b/kded/DESIGN
@@ -6,9 +6,9 @@ cache of servicetypes, mimetypes and services, for a particular user.
It uses KDirWatch to monitor the directories contain the .desktop files.
When a file is added/removed, it waits 5 seconds (in case of series of
-updates), and then launches kbuildsycoca.
+updates), and then launches tdebuildsycoca.
-kbuildsycoca recreates the sycoca file by:
+tdebuildsycoca recreates the sycoca file by:
* parsing all .desktop files, replacing global ones by local ones (at any
level of the hierarchy)
* creating all objects in memory
diff --git a/kded/Makefile.am b/kded/Makefile.am
index 1baf30e4f..093b5db0e 100644
--- a/kded/Makefile.am
+++ b/kded/Makefile.am
@@ -20,15 +20,15 @@
INCLUDES= -I$(srcdir)/.. -I$(top_srcdir) $(all_includes)
lib_LTLIBRARIES =
-tdeinit_LTLIBRARIES = kded.la kbuildsycoca.la
+tdeinit_LTLIBRARIES = kded.la tdebuildsycoca.la
kded_la_LDFLAGS = $(all_libraries) -module -avoid-version
kded_la_LIBADD = $(LIB_KIO) $(LIB_QT) $(LIB_TDECORE) $(top_builddir)/dcop/libDCOP.la $(LIB_X11)
kded_la_SOURCES = kded.cpp kdedmodule.cpp
-kbuildsycoca_la_LDFLAGS = $(all_libraries) -module -avoid-version
-kbuildsycoca_la_LIBADD = $(LIB_KIO) $(LIB_QT) $(top_builddir)/dcop/libDCOP.la $(LIB_TDECORE)
-kbuildsycoca_la_SOURCES = kbuildsycoca.cpp kbuildservicetypefactory.cpp \
+tdebuildsycoca_la_LDFLAGS = $(all_libraries) -module -avoid-version
+tdebuildsycoca_la_LIBADD = $(LIB_KIO) $(LIB_QT) $(top_builddir)/dcop/libDCOP.la $(LIB_TDECORE)
+tdebuildsycoca_la_SOURCES = tdebuildsycoca.cpp kbuildservicetypefactory.cpp \
kbuildservicefactory.cpp \
kbuildservicegroupfactory.cpp \
kbuildimageiofactory.cpp \
@@ -36,25 +36,25 @@ kbuildsycoca_la_SOURCES = kbuildsycoca.cpp kbuildservicetypefactory.cpp \
kctimefactory.cpp \
vfolder_menu.cpp
-bin_PROGRAMS = kdontchangethehostname kde-menu kmimelist
+bin_PROGRAMS = kdontchangethehostname tde-menu tdemimelist
kdontchangethehostname_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
kdontchangethehostname_LDADD = $(LIB_TDECORE)
kdontchangethehostname_SOURCES = khostname.cpp
-kmimelist_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
-kmimelist_LDADD = ../kio/libkio.la
-kmimelist_SOURCES = kmimelist.cpp
+tdemimelist_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
+tdemimelist_LDADD = ../tdeio/libtdeio.la
+tdemimelist_SOURCES = tdemimelist.cpp
kde_menu_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
kde_menu_LDADD = $(LIB_KIO)
-kde_menu_SOURCES = kde-menu.cpp
+kde_menu_SOURCES = tde-menu.cpp
METASOURCES = AUTO
include_HEADERS = kdedmodule.h
-noinst_HEADERS = kbuildsycoca.h kbuildservicetypefactory.h \
+noinst_HEADERS = tdebuildsycoca.h kbuildservicetypefactory.h \
kbuildservicefactory.h kbuildservicegroupfactory.h \
kbuildimageiofactory.h kresourcelist.h \
kbuildprotocolinfofactory.h
@@ -65,7 +65,7 @@ servicetypedir = $(kde_servicetypesdir)
xdg_menu_DATA = applications.menu applications.menu-no-kde
update_DATA = kded.upd
-updatedir = $(kde_datadir)/kconf_update
+updatedir = $(kde_datadir)/tdeconf_update
include $(top_srcdir)/admin/Doxyfile.am
diff --git a/kded/README.kded b/kded/README.kded
index 1cf382279..7265a1084 100644
--- a/kded/README.kded
+++ b/kded/README.kded
@@ -7,19 +7,19 @@ Some of these tasks are built in, others are started on demand.
Built in tasks
==============
*) Checking for newly installed software and updating tdesycoca when new
-software is detected. Updating of tdesycoca is done by the program kbuildsycoca
+software is detected. Updating of tdesycoca is done by the program tdebuildsycoca
which gets started by kded. When kded is first started it always runs
-kbuildsycoca to ensure that tdesycoca is up to date.
+tdebuildsycoca to ensure that tdesycoca is up to date.
*) Checking for newly installed update files. Applications can install
*.upd update files. These *.upd files are used to update configuration files
of users, primarily when new versions of applications are installed with
(slightly) different configuration file formats. Updating of configuration
-files is done by kconf_update. kded starts kconf_update when it detects a
-new update file. When kded is first started it always runs kconf_update to
-ensure that it has not missed any update files. kconf_update keeps track
+files is done by tdeconf_update. kded starts tdeconf_update when it detects a
+new update file. When kded is first started it always runs tdeconf_update to
+ensure that it has not missed any update files. tdeconf_update keeps track
of which update files have been processed already in the config-file
-kconf_updaterc. It only performs a certain update once.
+tdeconf_updaterc. It only performs a certain update once.
*) Checking for hostname changes. It is a really bad idea to change the
hostname of a running system and it usually only happens with incorrectly
@@ -42,12 +42,12 @@ and has a default of 5000 (5 seconds).
CheckSycoca: This option can be used to disable checking for new software.
tdesycoca will still be built when kded starts up and when applications
explicitly request a rebuild of the tdesycoca database. The user can
-also manually rebuild tdesycoca by running the kbuildsycoca program.
+also manually rebuild tdesycoca by running the tdebuildsycoca program.
The default value of this option is "true". Checking can be disabled by
setting this option to "false".
CheckUpdates: This option can be used to disable checking for update files.
-kconf_update will still be run when kded starts up.
+tdeconf_update will still be run when kded starts up.
The default value of this option is "true". Checking can be disabled by
setting this option to "false".
diff --git a/kded/kded.h b/kded/kded.h
index 93aac0ab6..a4968624a 100644
--- a/kded/kded.h
+++ b/kded/kded.h
@@ -37,7 +37,7 @@
class KDirWatch;
class KService;
-// No need for this in libkio - apps only get readonly access
+// No need for this in libtdeio - apps only get readonly access
class Kded : public TQObject, public DCOPObject, public DCOPObjectProxy
{
Q_OBJECT
diff --git a/kded/kdedmodule.cpp b/kded/kdedmodule.cpp
index ca28a5c62..6371b2534 100644
--- a/kded/kdedmodule.cpp
+++ b/kded/kdedmodule.cpp
@@ -24,7 +24,7 @@
#include "kded.h"
#include "kdedmodule.h"
-#include "kconfigdata.h"
+#include "tdeconfigdata.h"
typedef TQMap<KEntryKey, KSharedPtr<KShared> > KDEDObjectMap;
diff --git a/kded/kde-menu.cpp b/kded/tde-menu.cpp
index 5c1a38b4d..6a8721915 100644
--- a/kded/kde-menu.cpp
+++ b/kded/tde-menu.cpp
@@ -42,7 +42,7 @@ static KCmdLineOptions options[] = {
KCmdLineLastOption
};
-static const char appName[] = "kde-menu";
+static const char appName[] = "tde-menu";
static const char appVersion[] = "1.0";
static bool utf8;
@@ -60,7 +60,7 @@ static void result(const TQString &txt)
static void error(int exitCode, const TQString &txt)
{
- tqWarning("kde-menu: %s", txt.local8Bit().data());
+ tqWarning("tde-menu: %s", txt.local8Bit().data());
exit(exitCode);
}
@@ -113,7 +113,7 @@ int main(int argc, char **argv)
"The --highlight option can be used to visually indicate to the user where\n"
"in the TDE menu a specific application is located.");
- TDEAboutData d(appName, I18N_NOOP("kde-menu"), appVersion,
+ TDEAboutData d(appName, I18N_NOOP("tde-menu"), appVersion,
description,
TDEAboutData::License_GPL, "(c) 2003 Waldo Bastian");
d.addAuthor("Waldo Bastian", I18N_NOOP("Author"), "bastian@kde.org");
@@ -146,11 +146,11 @@ int main(int argc, char **argv)
TQStringList args;
args.append("--incremental");
args.append("--checkstamps");
- TQString command = "kbuildsycoca";
+ TQString command = "tdebuildsycoca";
TQCString _launcher = TDEApplication::launcher();
if (!DCOPRef(_launcher, _launcher).call("tdeinit_exec_wait", command, args).isValid())
{
- tqWarning("Can't talk to klauncher!");
+ tqWarning("Can't talk to tdelauncher!");
command = TDEGlobal::dirs()->findExe(command);
command += " " + args.join(" ");
system(command.local8Bit());
diff --git a/kded/kbuildsycoca.h b/kded/tdebuildsycoca.h
index 443f5b120..51e7af337 100644
--- a/kded/kbuildsycoca.h
+++ b/kded/tdebuildsycoca.h
@@ -15,8 +15,8 @@
* the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
* Boston, MA 02110-1301, USA.
**/
-#ifndef __kbuildsycoca_h__
-#define __kbuildsycoca_h__
+#ifndef __tdebuildsycoca_h__
+#define __tdebuildsycoca_h__
#include <sys/stat.h>
@@ -34,7 +34,7 @@
class TQDataStream;
-// No need for this in libkio - apps only get readonly access
+// No need for this in libtdeio - apps only get readonly access
class KBuildSycoca : public KSycoca
{
Q_OBJECT
diff --git a/kded/kmimelist.cpp b/kded/tdemimelist.cpp
index c82f6d9f7..c82f6d9f7 100644
--- a/kded/kmimelist.cpp
+++ b/kded/tdemimelist.cpp
diff --git a/kded/kded.cpp b/kded/kded.cpp
index 11c46e064..b769fa508 100644
--- a/kded/kded.cpp
+++ b/kded/kded.cpp
@@ -45,7 +45,7 @@
#include <kdirwatch.h>
#include <kstandarddirs.h>
#include <kdatastream.h>
-#include <kio/global.h>
+#include <tdeio/global.h>
#include <kservicetype.h>
#ifdef Q_WS_X11
@@ -65,27 +65,27 @@ static void runBuildSycoca(TQObject *callBackObj=0, const char *callBackSlot=0)
if(checkStamps)
args.append("--checkstamps");
if(delayedCheck)
- args.append("--nocheckfiles");
+ args.append("--nochectdefiles");
else
checkStamps = false; // useful only during kded startup
if (callBackObj)
{
TQByteArray data;
TQDataStream dataStream( data, IO_WriteOnly );
- dataStream << TQString("kbuildsycoca") << args;
+ dataStream << TQString("tdebuildsycoca") << args;
TQCString _launcher = TDEApplication::launcher();
kapp->dcopClient()->callAsync(_launcher, _launcher, "tdeinit_exec_wait(TQString,TQStringList)", data, callBackObj, callBackSlot);
}
else
{
- TDEApplication::tdeinitExecWait( "kbuildsycoca", args );
+ TDEApplication::tdeinitExecWait( "tdebuildsycoca", args );
}
}
static void runKonfUpdate()
{
- TDEApplication::tdeinitExecWait( "kconf_update", TQStringList(), 0, 0, "0" /*no startup notification*/ );
+ TDEApplication::tdeinitExecWait( "tdeconf_update", TQStringList(), 0, 0, "0" /*no startup notification*/ );
}
static void runDontChangeHostname(const TQCString &oldName, const TQCString &newName)
@@ -97,7 +97,7 @@ static void runDontChangeHostname(const TQCString &oldName, const TQCString &new
}
Kded::Kded(bool checkUpdates, bool new_startup)
- : DCOPObject("kbuildsycoca"), DCOPObjectProxy(),
+ : DCOPObject("tdebuildsycoca"), DCOPObjectProxy(),
b_checkUpdates(checkUpdates),
m_needDelayedCheck(false),
m_newStartup( new_startup )
@@ -665,7 +665,7 @@ KUpdateD::KUpdateD()
TQObject::connect( m_pDirWatch, TQT_SIGNAL(dirty(const TQString&)),
this, TQT_SLOT(slotNewUpdateFile()));
- TQStringList dirs = TDEGlobal::dirs()->findDirs("data", "kconf_update");
+ TQStringList dirs = TDEGlobal::dirs()->findDirs("data", "tdeconf_update");
for( TQStringList::ConstIterator it = dirs.begin();
it != dirs.end();
++it )
@@ -957,7 +957,7 @@ extern "C" KDE_EXPORT int kdemain(int argc, char *argv[])
// During startup kdesktop waits for KDED to finish.
// Send a notifyDatabaseChanged signal even if the database hasn't
// changed.
// If the database changed, kbuildsycoca's signal didn't go anywhere
// anyway, because it was too early, so let's send this signal
// unconditionnally (David)
TQByteArray data;
@@ -957,7 +957,7 @@ extern "C" KDE_EXPORT int kdemain(int argc, char *argv[])
// Send a notifyDatabaseChanged signal even if the database hasn't
// changed.
- // If the database changed, kbuildsycoca's signal didn't go anywhere
+ // If the database changed, tdebuildsycoca's signal didn't go anywhere
// anyway, because it was too early, so let's send this signal
// unconditionnally (David)
diff --git a/kded/kbuildsycoca.cpp b/kded/tdebuildsycoca.cpp
index 13a645395..47b7a9bf4 100644
--- a/kded/kbuildsycoca.cpp
+++ b/kded/tdebuildsycoca.cpp
@@ -21,7 +21,7 @@
#include <tqeventloop.h>
#include <config.h>
-#include "kbuildsycoca.h"
+#include "tdebuildsycoca.h"
#include "kresourcelist.h"
#include "vfolder_menu.h"
@@ -53,7 +53,7 @@
#include <kcrash.h>
#ifdef KBUILDSYCOCA_GUI // KBUILDSYCOCA_GUI is used on win32 to build
// GUI version of kbuildsycoca, so-called "kbuildsycocaw".
# include <tqlabel.h>
# include <kmessagebox.h>
bool silent;
@@ -463,7 +463,7 @@ bool KBuildSycoca::recreate()
{
TQString path(sycocaPath());
#ifdef Q_WS_WIN
- printf("kbuildsycoca: path='%s'\n", (const char*)path);
+ printf("tdebuildsycoca: path='%s'\n", (const char*)path);
#endif
// KSaveFile first writes to a temp file.
@@ -476,9 +476,9 @@ bool KBuildSycoca::recreate()
}
if (database->status() != 0)
{
- fprintf(stderr, "[kbuildsycoca] ERROR creating database '%s'! %s\n", path.local8Bit().data(),strerror(database->status()));
+ fprintf(stderr, "[tdebuildsycoca] ERROR creating database '%s'! %s\n", path.local8Bit().data(),strerror(database->status()));
#ifdef KBUILDSYCOCA_GUI // KBUILDSYCOCA_GUI is used on win32 to build
// GUI version of kbuildsycoca, so-called "kbuildsycocaw".
if (!silent)
KMessageBox::error(0, i18n("Error creating database '%1'.\nCheck that the permissions are correct on the directory and the disk is not full.\n").arg(path.local8Bit().data()), i18n("KBuildSycoca"));
#endif
@@ -505,11 +505,11 @@ bool KBuildSycoca::recreate()
m_str = 0L;
if (!database->close())
{
- fprintf(stderr, "[kbuildsycoca] ERROR writing database '%s'!\n", database->name().local8Bit().data());
- fprintf(stderr, "[kbuildsycoca] Disk full?\n");
+ fprintf(stderr, "[tdebuildsycoca] ERROR writing database '%s'!\n", database->name().local8Bit().data());
+ fprintf(stderr, "[tdebuildsycoca] Disk full?\n");
#ifdef KBUILDSYCOCA_GUI
if (!silent)
- KMessageBox::error(0, i18n("[kbuildsycoca] Error writing database '%1'.\nCheck that the permissions are correct on the directory and the disk is not full.\n").arg(path.local8Bit().data()), i18n("KBuildSycoca"));
+ KMessageBox::error(0, i18n("[tdebuildsycoca] Error writing database '%1'.\nCheck that the permissions are correct on the directory and the disk is not full.\n").arg(path.local8Bit().data()), i18n("KBuildSycoca"));
#endif
return false;
}
@@ -695,7 +695,7 @@ static KCmdLineOptions options[] = {
{ "nosignal", I18N_NOOP("Do not signal applications to update"), 0 },
{ "noincremental", I18N_NOOP("Disable incremental update, re-read everything"), 0 },
{ "checkstamps", I18N_NOOP("Check file timestamps"), 0 },
- { "nocheckfiles", I18N_NOOP("Disable checking files (dangerous)"), 0 },
+ { "nochectdefiles", I18N_NOOP("Disable checking files (dangerous)"), 0 },
{ "global", I18N_NOOP("Create global database"), 0 },
{ "menutest", I18N_NOOP("Perform menu generation test run only"), 0 },
{ "track <menu-id>", I18N_NOOP("Track menu id for debug purposes"), 0 },
@@ -706,7 +706,7 @@ static KCmdLineOptions options[] = {
KCmdLineLastOption
};
-static const char appName[] = "kbuildsycoca";
+static const char appName[] = "tdebuildsycoca";
static const char appVersion[] = "1.1";
class WaitForSignal : public QObject
@@ -777,14 +777,14 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
TQCString registeredName = dcopClient->registerAs(appName, false);
if (registeredName.isEmpty())
{
- fprintf(stderr, "[kbuildsycoca] Warning: %s is unable to register with DCOP.\n", appName);
+ fprintf(stderr, "[tdebuildsycoca] Warning: %s is unable to register with DCOP.\n", appName);
break;
}
else if (registeredName == appName)
{
break; // Go
}
- fprintf(stderr, "[kbuildsycoca] Waiting for already running %s to finish.\n", appName);
+ fprintf(stderr, "[tdebuildsycoca] Waiting for already running %s to finish.\n", appName);
dcopClient->setNotifications( true );
while (dcopClient->isApplicationRegistered(appName))
@@ -796,12 +796,12 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
}
dcopClient->setNotifications( false );
}
- fprintf(stderr, "[kbuildsycoca] %s running...\n", appName);
+ fprintf(stderr, "[tdebuildsycoca] %s running...\n", appName);
- bool checkfiles = bGlobalDatabase || args->isSet("checkfiles");
+ bool chectdefiles = bGlobalDatabase || args->isSet("chectdefiles");
- bool incremental = !bGlobalDatabase && args->isSet("incremental") && checkfiles;
- if (incremental || !checkfiles)
+ bool incremental = !bGlobalDatabase && args->isSet("incremental") && chectdefiles;
+ if (incremental || !chectdefiles)
{
KSycoca::self()->disableAutoRebuild(); // Prevent deadlock
TQString current_language = TDEGlobal::locale()->language();
@@ -814,14 +814,14 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
(KSycoca::self()->timeStamp() == 0))
{
incremental = false;
- checkfiles = true;
+ chectdefiles = true;
delete KSycoca::self();
}
}
g_changeList = new TQStringList;
- bool checkstamps = incremental && args->isSet("checkstamps") && checkfiles;
+ bool checkstamps = incremental && args->isSet("checkstamps") && chectdefiles;
TQ_UINT32 filestamp = 0;
TQStringList oldresourcedirs;
if( checkstamps && incremental )
@@ -861,7 +861,7 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
newTimestamp = (TQ_UINT32) time(0);
- if( checkfiles && ( !checkstamps || !KBuildSycoca::checkTimestamps( filestamp, oldresourcedirs )))
+ if( chectdefiles && ( !checkstamps || !KBuildSycoca::checkTimestamps( filestamp, oldresourcedirs )))
{
TQCString qSycocaPath = TQFile::encodeName(sycocaPath());
cSycocaPath = qSycocaPath.data();
@@ -870,7 +870,7 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
g_ctimeDict = 0;
if (incremental)
{
- tqWarning("[kbuildsycoca] Reusing existing tdesycoca.");
+ tqWarning("[tdebuildsycoca] Reusing existing tdesycoca.");
KSycoca *oldSycoca = KSycoca::self();
KSycocaFactoryList *factories = new KSycocaFactoryList;
g_allEntries = new KSycocaEntryListList;
@@ -950,10 +950,10 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
#ifdef KBUILDSYCOCA_GUI
if (!silent) {
progress.close();
- KMessageBox::information(0, i18n("[kbuildsycoca] Configuration information reloaded successfully."), capt);
+ KMessageBox::information(0, i18n("[tdebuildsycoca] Configuration information reloaded successfully."), capt);
}
#endif
return 0;
}
-#include "kbuildsycoca.moc"
+#include "tdebuildsycoca.moc"
@@ -53,7 +53,7 @@
#include <kcrash.h>
#ifdef KBUILDSYCOCA_GUI // KBUILDSYCOCA_GUI is used on win32 to build
- // GUI version of kbuildsycoca, so-called "kbuildsycocaw".
+ // GUI version of tdebuildsycoca, so-called "tdebuildsycocaw".
# include <tqlabel.h>
# include <kmessagebox.h>
@@ -476,9 +476,9 @@ bool KBuildSycoca::recreate()
#ifdef KBUILDSYCOCA_GUI // KBUILDSYCOCA_GUI is used on win32 to build
- // GUI version of kbuildsycoca, so-called "kbuildsycocaw".
+ // GUI version of tdebuildsycoca, so-called "tdebuildsycocaw".
if (!silent)
KMessageBox::error(0, i18n("Error creating database '%1'.\nCheck that the permissions are correct on the directory and the disk is not full.\n").arg(path.local8Bit().data()), i18n("KBuildSycoca"));